==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomUrl.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomUrl</code></p>
 */
public class DomUrl extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomUrl::<wbr>DomUrl()</code></p>
     */
    public DomUrl(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomUrl instance);
    
    /**
     * <p>See <code>DomUrl::<wbr>clearElementString()</code></p>
     */
    @QtUninvokable
    public final void clearElementString(){
        clearElementString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementString_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr>elementString()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomString elementString(){
        return elementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomString elementString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr>hasElementString()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementString(){
        return hasElementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomUrl::<wbr>setElementString(DomString*)</code></p>
     */
    @QtUninvokable
    public final void setElementString(io.qt.uic.ui4.@Nullable DomString a){
        setElementString_native_DomString_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementString_native_DomString_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomUrl::<wbr>takeElementString()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomString takeElementString(){
        return takeElementString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomString takeElementString_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomUrl::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomUrl(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.7-sources.jar: io/qt/uic/ui4/DomUrl.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomUrl</code></p>
 * @hidden
 */
public class DomUrl extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomUrl::<wbr/>DomUrl()</code></p>
     */
    public DomUrl(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomUrl instance);
    
    /**
     * <p>See <code>DomUrl::<wbr/>clearElementString()</code></p>
     */
    @QtUninvokable
    public final void clearElementString(){
        clearElementString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementString_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr/>elementString()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomString elementString(){
        return elementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomString elementString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr/>hasElementString()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementString(){
        return hasElementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomUrl::<wbr/>setElementString(DomString*)</code></p>
     */
    @QtUninvokable
    public final void setElementString(io.qt.uic.ui4.@Nullable DomString a){
        setElementString_native_DomString_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementString_native_DomString_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomUrl::<wbr/>takeElementString()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomString takeElementString(){
        return takeElementString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomString takeElementString_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomUrl::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomUrl(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
